#!/usr/bin/python

import sys, argparse, re

#
# command line argument handling
#
arg_parser = argparse.ArgumentParser ( prog="gp_decode.py", description="Converts phonological transcriptions in crf format into human readable IPA format" )

# input
arg_parser.add_argument('IN', nargs='?', help='input', default=sys.stdin, type=argparse.FileType('r'))

# output
arg_parser.add_argument( '-o', "--output", nargs='?', help='output', default=sys.stdout, type=argparse.FileType('w'))

# mode
arg_parser.add_argument('-m', "--mode", help='Operation mode', choices=['rate', 'print'], default='print')

# keep input
arg_parser.add_argument('-i', "--input", help="Print unsegmented input word.", action="store_true")

args = arg_parser.parse_args ()

prev_word = u""
word = u""
output = []
prob = u""
for line in args.IN:
	line = unicode(line.strip(),"utf-8")

	if not line:
            if prev_word and prev_word != word:
                args.output.write('\n')	
            if args.input:
                args.output.write("%s\t" % word.encode("utf-8"))

            if args.mode == "rate":
                args.output.write(" ".join(graphon.encode("utf-8") for graphon in output))
            else:
                args.output.write("".join(phon.encode("utf-8") for phon in output))

            if prob:
                args.output.write("\t%s" % prob.encode("utf-8"))
            args.output.write('\n')
            prev_word = word
            word = u""
            output = []
            prob = u""

        elif line.startswith("#"):
            # prob
            prob_obj = re.search("^# [0-9] ([0-9]+[\.][0-9]+)$", line)
            if prob_obj:
                prob = prob_obj.group(1)
            else:
                continue

	else:
            fields = line.split("\t")
            word += fields[0]
            if args.mode == "rate":
                output.append(u"%s,%s" % (fields[0],fields[1]))
            elif args.mode == "print":
                output.append(u"%s" % ("".join(graphone.split(u",")[-1] for graphone in fields[1].split(u" "))))
            else:
                output.append(fields[1])
    
if output:
    if args.input:
        args.output.write("%s\t" % word.encode("utf-8"))

    if args.mode == "rate":
        args.output.write(" ".join(graphon.encode("utf-8") for graphon in output))
    else:
        args.output.write("".join(phon.encode("utf-8") for phon in output))

    if prob:
        args.output.write("\t%s" % prob.encode("utf-8"))
    args.output.write('\n')	
